<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://wpsolution.org
 * @since      1.0.0
 *
 * @package    Wps_Telegram_Chat
 * @subpackage Wps_Telegram_Chat/admin/partials
 */

	// get this plugin as name
	$thisPlugin = $this->plugin_name;
	
	$cfg = array();
	$cfg['url'] = plugin_dir_url(dirname(__DIR__));
	$cfg['path'] = plugin_dir_path(dirname(__DIR__));
	$cfg['data'] = get_plugin_data( $cfg['path'].$thisPlugin.'.php' );
	
	// Получаем значения полей плагина
	$options = $this->options;
	
	// Schedule
	$daysOfWeek = shiftArr(array('sun','mon','tue','wed','thu','fri','sat'), get_option('start_of_week'));
	$timeFormat = strripos(get_option('time_format'), ' a') == false ? 0 : 1;
	
	function shiftArr(array $arr, int $n): array{
		$n = $n % count($arr);
		$slice = array_splice($arr, $n);
		return array_merge($slice, $arr);
	}
	
	// add custom var
	$options['ajaxUrl'] = admin_url('admin-ajax.php');
	$options['timeFormat'] = $timeFormat;

?>

<script>var wpsTelegramChat = <?php echo wp_json_encode($options); ?></script>
<div id="<?php echo esc_attr($thisPlugin); ?>">

	<div id="infoBlock">
		<!--div id="authorLogo">
			<?php echo '<img src="' . esc_url($cfg['url'] . 'public/img/wpsolution.svg') . '" alt="">'; ?>
		</div-->
		<div id="info">
			<h2><?php echo esc_html($cfg['data']['Name']); ?></h2>
			Version <?php echo esc_html($cfg['data']['Version']); ?> By
			<a href="<?php echo esc_url($cfg['data']['AuthorURI']); ?>" target="_blank">
				<?php echo esc_html($cfg['data']['AuthorName']); ?> </a><br>
			For more information
			<a href="<?php echo esc_url($cfg['data']['PluginURI']); ?>" target="_blank">
				Visit plugin site </a><br>
		</div>
	</div>
	
	<form method="post" action="options.php">
	
		<?php // Выводит скрытые поля формы страницы настроек, к ним добавим свои
			settings_fields( $thisPlugin );
			do_settings_sections( $thisPlugin );
		?>
		
		<h3><?php _e('Bot options', $thisPlugin); ?></h3>
		
		<div id="chatOptions">
			<div id="chatEnabled">
				<label>
					<span><?php _e('Enabled', $thisPlugin); ?></span>
					<input type="checkbox" name="<?php echo esc_attr($thisPlugin.'[enabled]'); ?>"
						value="1" <?php echo checked( '1', $options['enabled'] ); ?>
					/>
				</label>
				<p></p>
			</div>
			
			<div id="chatToken">
				<label>
					<span><?php _e('Authentication token', $thisPlugin); ?></span>
					<input type="text" name="<?php echo esc_attr($thisPlugin.'[token]'); ?>"
						   value="<?php echo esc_attr($options['token']);?>"
						   placeholder="XXX:YYYYYYY"
					/>
				</label>
				<p>
					<?php _e('Each bot is given a unique authentication <b>token</b> when it is created.
					The token looks something like <code>123456:ABC-DEF1234ghIkl-zyx57W2v1u123ew11</code>.
					You can learn about obtaining tokens and generating new ones in
					<a target="_blank" href="https://core.telegram.org/bots#6-botfather">this document</a>.',
					$thisPlugin); ?>
				</p>
			</div>
			
			<div id="chatId">
				<label>
					<span><?php _e('Telegram chat ID', $thisPlugin); ?></span>
					<input type="text" name="<?php echo esc_attr($thisPlugin.'[chatId]'); ?>"
						   value="<?php echo esc_attr($options['chatId']); ?>"
						   placeholder="XXXXXXXXX"
					/>
				</label>
				<p>
					<?php _e('In the telegram messenger every user, chat, and group is having a unique ID.
					So To prevent any unauthorized access to our bots from other users we need to
					<a target="_blank" href="https://t.me/getmyid_bot">
					find our chat ID</a>.',
					$thisPlugin); ?>
				</p>
			</div>
			
			<div id="chatWebHook">
				<label>
					<span><?php _e('WebHook', $thisPlugin); ?></span>
					<!--input type="text" name="<?php echo esc_attr($thisPlugin.'[webHook]'); ?>"
						   value="<?php echo esc_attr($options['webHook']); ?>"
					/-->
				</label>
				<div>
					<button type="button" id="chatGetWebHook"><?php _e('Check webHook', $thisPlugin); ?></button>
					<!--button type="button" id="chatSetWebHook"><?php _e('Set webHook', $thisPlugin); ?></button-->
					<button type="button" id="chatDelWebHook"><?php _e('Delete webHook', $thisPlugin); ?></button>
				</div>
				<br><p class="info"></p>
				<p>
					<?php _e('There are two mutually exclusive ways of receiving updates for your bot -
					the <b>getUpdates</b> method on one hand and <b>webHook</b> on the other. We need to be able 
					to connect and post updates with <b>getUpdates</b> method. This method will not work if an outgoing 
					<b>webHook</b> is set up.',
					$thisPlugin); ?>
				</p>
			</div>
			
        </div>
		
		<h3><?php _e('Chat Theme', $thisPlugin); ?></h3>
		
		<div id="chatTheme">
			
			<div id="chatTitle">
				<label>
					<span><?php _e('Title', $thisPlugin); ?></span>
					<input type="text" name="<?php echo esc_attr($thisPlugin.'[chatTitle]'); ?>"
						   value="<?php echo esc_attr($options['chatTitle']); ?>"
					/>
				</label>
			</div>
			
			<div id="chatWelcomeTxt">
				<label>
					<span><?php _e('Welcome Text', $thisPlugin); ?></span>
					<textarea name="<?php echo esc_attr($thisPlugin.'[chatWelcomeTxt]'); ?>"
						><?php echo esc_attr($options['chatWelcomeTxt']); ?></textarea>
				</label>
			</div>
			
			<div id="chatOfflineTxt">
				<label>
					<span><?php _e('Offline Message', $thisPlugin); ?></span>
					<textarea name="<?php echo esc_attr($thisPlugin.'[chatOfflineTxt]'); ?>"
						><?php echo esc_attr($options['chatOfflineTxt']); ?></textarea>
				</label>
				<p>
					<?php _e('If the user does not receive a response within the first minute
					and depending on the "Schedule" an "Offline Message" will be displayed.',
					$thisPlugin); ?>
				</p>
			</div>
			
			<div id="chatTelegramLink">
				<label>
					<span><?php _e('Telegram Link', $thisPlugin); ?></span>
					<input type="text" name="<?php echo esc_attr($thisPlugin.'[chatTelegramLink]'); ?>"
						   value="<?php echo esc_attr($options['chatTelegramLink']); ?>"
						   placeholder="https://t.me/username"
					/>
				</label>
				<p>
					<?php _e('Telegram links let people contact you without knowing your phone number,
					<a target="_blank" href="https://telegram.org/faq#usernames-and-t-me">Read more</a>.
					If the link is specified, then the telegram icon is shown in the chat header,
					clicking on which opens the Telegram App.',
					$thisPlugin); ?>
				</p>
			</div>
			
			<div id="chatImg">
				<div id="chatAnonimImg">
					<span class="img">
					<?php
						if($options['chatAnonimImg']){
							echo wp_get_attachment_image( $options['chatAnonimImg'], 'thumbnail' );
						}else{
							echo '<img src="' . esc_url($cfg['url'] . 'public/img/anonim-icon.svg') . '" alt="">';
						}
					?>
					</span>
					<input type="hidden" name="<?php echo esc_attr($thisPlugin.'[chatAnonimImg]'); ?>"
						value="<?php echo esc_attr($options['chatAnonimImg']); ?>"
					/>
					<label>
						<span><?php _e('Anonymous Avatar', $thisPlugin); ?></span>
						<br>
						<button type="button" id="chatGetAnonimImg"><?php _e('Change image', $thisPlugin); ?></button>
					</label>
				</div>
				
				<div id="chatBotImg">
					<span class="img">
					<?php
						if($options['chatBotImg']){
							echo wp_get_attachment_image( $options['chatBotImg'], 'thumbnail' );
						}else{
							echo '<img src="' . esc_url($cfg['url'] . 'public/img/bot-icon.svg') . '" alt="">';
						}
					?>
					</span>
					<input type="hidden" name="<?php echo esc_attr($thisPlugin.'[chatBotImg]'); ?>"
						value="<?php echo esc_attr($options['chatBotImg']); ?>"
					/>
					<label>
						<span><?php _e('Telegram Bot Avatar', $thisPlugin); ?></span>
						<br>
						<button type="button" id="chatGetBotImg"><?php _e('Change image', $thisPlugin); ?></button>
					</label>
				</div>
			</div>
			
		</div>
		
		<h3>
			<?php _e('Schedule', $thisPlugin);?>
			<i><?php echo ' - Current time: ' . wp_date( get_option('time_format') );?></i>
		</h3>
		
		<div id="chatSchedule">
		
			<div id="alwaysOnline">
				<label>
					<span><?php _e('Always onLine', $thisPlugin); ?></span>
					<input type="hidden" name="<?php echo esc_attr($thisPlugin.'[alwaysOnline]'); ?>" value="0" />
					<input type="checkbox" name="<?php echo esc_attr($thisPlugin.'[alwaysOnline]'); ?>"
						value="1" <?php checked( 1, $options['alwaysOnline'] ); ?>
					/>
				</label>
				<p></p>
			</div>
			
			<div id="daysOfWeek">
				
				<?php for ($d = 0; $d < 7; $d++) { ?>
				<div id="<?php echo esc_html($daysOfWeek[$d]); ?>" class="dayBox">
					<label>
						<span class="dayName"><?php echo sprintf(__('%s', $thisPlugin), $daysOfWeek[$d]); ?></span>
						<input type="checkbox"
							name="<?php echo esc_attr($thisPlugin.'[' . $daysOfWeek[$d] . ']'); ?>"
							value="<?php echo esc_attr($options[ $daysOfWeek[$d] ]); ?>"
						/>
					</label>
					<div class="startTime">
						<span><?php _e('Start', $thisPlugin); ?></span>
						<label>
							<span><?php _e('H:', $thisPlugin); ?></span>
							<select>
								<?php
									for ($h = $timeFormat; $h < 24-11*$timeFormat; $h++){
										$value = str_pad($h, 2, '0', STR_PAD_LEFT);
								?>
								<option value="<?php echo esc_attr($value); ?>">
									<?php echo esc_attr($value); ?>
								</option>
								<?php } ?>
							</select>
						</label>
						<label>
							<span><?php _e('M:', $thisPlugin); ?></span>
							<select>
								<?php
									for ($m = 0; $m < 60; $m += 5){
										$value = str_pad($m, 2, '0', STR_PAD_LEFT);
								?>
								<option value="<?php echo esc_attr($value); ?>">
									<?php echo esc_attr($value); ?>
								</option>
								<?php } ?>
							</select>
						</label>
						<?php if($timeFormat){ ?>
						<label class="timeFormat">
							<select>
								<option value="am">AM</option>
								<option value="pm">PM</option>
							</select>
						</label>
						<?php } ?>
					</div>
					<div class="endTime">
						<span><?php _e('End', $thisPlugin); ?></span>
						<label>
							<span><?php _e('H:', $thisPlugin); ?></span>
							<select>
								<?php
									for ($h = $timeFormat; $h < 24-11*$timeFormat; $h++){
										$value = str_pad($h, 2, '0', STR_PAD_LEFT);
								?>
								<option value="<?php echo esc_attr($value); ?>">
									<?php echo esc_attr($value); ?>
								</option>
								<?php } ?>
							</select>
						</label>
						<label>
							<span><?php _e('M:', $thisPlugin); ?></span>
							<select>
								<?php
									for ($m = 0; $m < 60; $m += 5){
										$value = str_pad($m, 2, '0', STR_PAD_LEFT);
								?>
								<option value="<?php echo esc_attr($value); ?>">
									<?php echo esc_attr($value); ?>
								</option>
								<?php } ?>
							</select>
						</label>
						<?php if($timeFormat){ ?>
						<label class="timeFormat">
							<select>
								<option value="pm">PM</option>
								<option value="am">AM</option>
							</select>
						</label>
						<?php } ?>
					</div>
				</div>
				<?php } ?>
				<p class="info">
					<?php _e('The start time must be less than the end time by at least 1 hour', $thisPlugin); ?>
				</p>
				<p></p>
			</div>
		</div>
		<input type="hidden" name="<?php echo esc_attr($thisPlugin.'[chatVer]'); ?>"
			value="<?php echo esc_attr($options['chatVer']); ?>" />
		<?php submit_button(__('Save all changes', $thisPlugin), 'primary', 'submit', TRUE); ?>
	</form>
	<button type="button" id="chatDeleteOptions" style="display:none;"> <?php _e('Delete Options', $thisPlugin); ?> </button>
</div>
