<?php

/**
 * @link       https://wpsolution.org
 * @since      1.0.0
 *
 * @package    Wps_Telegram_Chat
 * @subpackage Wps_Telegram_Chat/public/partials
 */
	
	global $cfg, $debug;
	$cfg = array();
	$cfg['cookie'] = array();
	$cfg['response'] = array();
	
	$cfg['thisPlugin'] = $this->plugin_name;
	$cfg['exData'] = __DIR__ . '/data.json';
	
	$nonce = wp_verify_nonce( $_POST['nonce'], $cfg['thisPlugin'] );
	if(!$nonce){
		echo '!NONSE';
		wp_die();
	}
	
	// Get plugin option fields
	$options = $this->options;
	
	if(isset( $_COOKIE[ $cfg['thisPlugin'] ]) ){
		
		$cfg['cookie'] = filter_var_array( json_decode( stripslashes( $_COOKIE[ $cfg['thisPlugin'] ] ), true ),
			[
				'user' => sanitize_user('user'),
				'nonce' => sanitize_key('nonce'),
				'lastUpdate' => FILTER_SANITIZE_NUMBER_INT,
				'lastUpdateType' => sanitize_html_class('lastUpdateType')
			]
		);
	}
	
	$cfg['mode'] = sanitize_html_class( $_POST['mode'] );
	$cfg['token'] = $options['token'];
	$cfg['chatId'] = $options['chatId'];
	$cfg['apiUrl'] = 'https://api.telegram.org/bot';
	$cfg['sendMessage'] = $cfg['apiUrl'] . $cfg['token'] . '/sendMessage';
	$cfg['getUpdates'] = $cfg['apiUrl'] . $cfg['token'] . '/getUpdates';
	$cfg['message'] = sanitize_textarea_field( $_POST['text'] );
	$cfg['user'] = '#User_' . getUserName();
	
	// delay before next request
	$cfg['time'] = time() - 4; // 4 seconds delay
	$cfg['lastUpdate'] = $cfg['cookie']['lastUpdate']; // last update for post
	$cfg['lastUpdate'] = $cfg['time'] < $cfg['lastUpdate'] ? true : false;
	
	if( $cfg['lastUpdate'] && $cfg['mode'] == $cfg['cookie']['lastUpdateType'] ){
		echo 'SPAM';
		wp_die();
	}
	
	$cfg['cookie']['lastUpdate'] = time();
	$cfg['cookie']['lastUpdateType'] = $cfg['mode'];

	if($cfg['mode'] == 'sendMessage' && $cfg['message']){ sendMessage(); }
	else if($cfg['mode'] == 'getUpdates'){ getUpdates(); }
	
	function getUserName(){
		global $cfg;
		$user = $cfg['cookie']['user'];
		
		if (!$user) {
			$user = wp_get_current_user()->display_name;
			
			if(!$user){ $user = mt_rand(123456789, 999999999); }
			$user = preg_replace('/[^a-zA-Z0-9_]/', '_', $user);
			
			$cfg['cookie']['user'] = $user;
		}
		return $user;
	}
	
	function getUpdates(){
		global $cfg, $debug;
		
		// read file
		$exData = file_get_contents($cfg['exData']);
		$exData = json_decode( $exData, true );
		if(!$exData){
			$exData = array();
			$exData['update_id'] = -1;
			$exData['data'] = array();
		}
		
		$fileUpdate = filemtime($cfg['exData']); // last update for file
		
		// clear the file if it has not been updated for 60 minutes
		if($cfg['time'] - 3600 > $fileUpdate){ file_put_contents( $cfg['exData'], '', LOCK_EX ); }
		
		$fileUpdate = $cfg['time'] < $fileUpdate ? true : false;
		
		if(!$fileUpdate && !$cfg['lastUpdate']){
			// get updates
			$offset = $exData['update_id'] + 1;
			if($offset){ $offset = '?offset=' . $offset; } else { $offset = ''; }
			$result = wp_remote_post( $cfg['getUpdates'] . $offset );
			
		}else{
			$result = array();
			$result['body'] = '{"ok":true,"result":[]}';
		}
		
		if ( is_wp_error($result) ) {
			// error
			$reply = array();
		}else{
			// response
			$reply = json_decode( $result['body'], true );
			if( !$reply || !$reply['ok'] ){ $reply = array(); }
			else{ $reply = $reply['result']; }

			foreach($reply as $key => $item){
				if($item['update_id']){
					$reply[ 'id_' . $item['update_id'] ] = $item;
					unset( $reply[$key] );
				}
			}
		}
		
		$data = array_merge($exData['data'], $reply);
		
		// procces data
		$toMessages = array();
		$toFile = array();
		$toFile['data'] = array();
		
		foreach($data as $item){
			$replyToMessage = $item['message']['reply_to_message'];
			
			$id = 'id_' . $item['update_id'];
			$date = $item['message']['date'];
			$text = $item['message']['text'];
			
			if($replyToMessage){
				preg_match('/#User_(.+)\n/', $replyToMessage['text'], $user);
				$user = $user[1];
				
				if($user == $cfg['cookie']['user']){
					$toMessages[] = array(
						'user' => $user,
						'date' => $date,
						'text' => $text
					);
				}else{
					$toFile['data'][$id] = $item;
				}
			}else{
				// service messages
				//$toFile['data'][$id] = $item;
			}
		}
		
		// update ID
		$reply_id = end($reply)['update_id'];
		if(!$reply_id){ $reply_id = 0; }
		
		$data_id = end($data)['update_id'];
		if(!$data_id){ $data_id = 0; }
		
		$update_id = max ( $exData['update_id'], $reply_id, $data_id );
		$toFile['update_id'] = $update_id;
		
		if( serialize($toFile['data']) != serialize($exData['data']) || $toFile['update_id'] != $exData['update_id'] ){
			// if the data has changed save to file
			file_put_contents( $cfg['exData'], json_encode($toFile), LOCK_EX );
		}
		
		$reply = array();
		$reply['toMessage'] = $toMessages;
		
		//$debug = true;
		
		$cfg['response']['result'] = $result;
		$cfg['response']['reply'] = $reply;
		$cfg['response']['exData'] = $toFile;
		$cfg['response']['debug'] = $debug;
	}
	
	function sendMessage(){
		global $cfg;
		$args = array(
			'body' => array(
				'text' => $cfg['user'] . PHP_EOL . $cfg['message'],
				'chat_id' => $cfg['chatId']
			)
		);
		
		$cfg['response']['result'] = wp_remote_post( $cfg['sendMessage'], $args );
	}
	
	saveCookie();
	function saveCookie(){
		global $cfg;
		setcookie( $cfg['thisPlugin'], json_encode($cfg['cookie']), time() + 1800, '/' );
	}
	
	$cfg['response']['cookie'] = $cfg['cookie'];
	
	echo wp_json_encode( $cfg['response'] );
	wp_die(); // exit;
	
?>